@@ -501,26 +501,13 @@ class ImSwitchServer(Worker):
         return {"available_setups": setup_list}
 
     @app.get("/UC2ConfigController/getCurrentSetupFilename")
-    def getCurrentSetupFilename():
+    def getCurrentSetupFilename() -> Dict[str, str]:
         """
         Returns the current setup filename.
         """
-        options, _ = imswitch.DEFAULT_SETUP_FILE # configfiletools.loadOptions()
-        return {"current_setup": options.setupFileName}
+        options = imswitch.DEFAULT_SETUP_FILE # configfiletools.loadOptions()
+        return {"current_setup": options}
 
-    @app.get("/UC2ConfigController/setSetupFileName")
-    def setSetupFileName(setupFileName: str, restartSoftware: bool=False) -> str:
-        '''Sets the setup file name in the options file.'''
-        if setupFileName is  None:
-            return "No setup file name provided."
-        if setupFileName not in configfiletools.getSetupList():
-            print(f"Setup file {setupFileName} does not exist.")
-            return f"Setup file {setupFileName} does not exist."
-        options, _ = configfiletools.loadOptions()
-        options = dataclasses.replace(options, setupFileName=setupFileName)
-        configfiletools.saveOptions(options)
-        if restartSoftware: ostools.restartSoftware()
-        return f"Setup file {setupFileName} set successfully."
 
     @app.get("/UC2ConfigController/readSetupFile")
     def readSetupFile(setupFileName: str=None) -> dict:
@@ -534,7 +521,7 @@ class ImSwitchServer(Worker):
             return f"Setup file {setupFileName} does not exist."
         mOptions = Options(setupFileName=setupFileName)
         setup_dict = configfiletools.loadSetupInfo(mOptions, ViewSetupInfo)
-        return setup_dict
+        return setup_dict.to_dict()
 
     @app.post("/UC2ConfigController/writeNewSetupFile")
     def writeNewSetupFile(setupFileName: str, setupDict: dict, setAsCurrentConfig: bool = True, restart: bool = False, overwrite: bool = False) -> str:
@@ -550,11 +537,30 @@ class ImSwitchServer(Worker):
         setupInfo = ViewSetupInfo.from_dict(setupDict)
         configfiletools.saveSetupInfo(mOptions, setupInfo)
         if setAsCurrentConfig:
-            pass #self.setSetupFileName(setupFileName) # TODO: This is not working
+            options, _ = configfiletools.loadOptions()
+            options = dataclasses.replace(options, setupFileName=setupFileName)
+            configfiletools.saveOptions(options)
+        if restart: 
+            ostools.restartSoftware()
+
         if restart:
             ostools.restartSoftware(forceConfigFile=setAsCurrentConfig)
         return f"Setup file {setupFileName} written successfully."
 
+    @app.get("/UC2ConfigController/setSetupFileName")
+    def setSetupFileName(setupFileName: str, restartSoftware: bool=False) -> str:
+        '''Sets the setup file name in the options file.'''
+        if setupFileName is  None:
+            return "No setup file name provided."
+        if setupFileName not in configfiletools.getSetupList():
+            print(f"Setup file {setupFileName} does not exist.")
+            return f"Setup file {setupFileName} does not exist."
+        options, _ = configfiletools.loadOptions()
+        options = dataclasses.replace(options, setupFileName=setupFileName)
+        configfiletools.saveOptions(options)
+        if restartSoftware: 
+            ostools.restartSoftware()
+        return f"Setup file {setupFileName} set successfully."
 
 
 # Copyright (C) 2020-2024 ImSwitch developers
